#!/bin/bash
#Description: DevKit constants
#Copyright: Copyright © Huawei Technologies Co., Ltd. 2023. All rights reserved.
#History: 2024-01-10 created

SUCCESS=0
APP_NOT_BINARY_ERROR='APP_NOT_BINARY_ERROR'
APP_PATH_PERMISSION_ERROR='APP_PATH_PERMISSION_ERROR'
APP_DIR_PATH_PERMISSION_ERROR='APP_DIR_PATH_PERMISSION_ERROR'
SOURCE_PATH_NOT_DIR_ERROR='SOURCE_PATH_NOT_DIR_ERROR'
SOURCE_PATH_PERMISSION_ERROR='SOURCE_PATH_PERMISSION_ERROR'
APP_IS_LINK_ERROR='APP_IS_LINK_ERROR'
SOURCE_PATH_IS_LINK_ERROR='SOURCE_PATH_IS_LINK_ERROR'
APP_NOT_EXIT_ERROR='APP_NOT_EXIT_ERROR'
SOURCE_PATH_NOT_EXIT_ERROR='SOURCE_PATH_NOT_EXIT_ERROR'
RETURN_SUCCESS='SUCCESS'

function pre_check_path() {
    # 判断二进制所在路径有无Linux用户的可读、可写、可执行权限
    test -r ${mpi_app_dir_path} -a -w ${mpi_app_dir_path} -a -x ${mpi_app_dir_path}
    if [[ "$?" -ne "${SUCCESS}" ]]; then
        echo ${APP_DIR_PATH_PERMISSION_ERROR}
        return
    fi
    # 判断二进制文件是否存在
    if [ ! -e ${mpi_app_path} ]; then
        echo ${APP_NOT_EXIT_ERROR}
        return
    fi
    # 判断二进制文件有无Linux用户的可读权限
    test -r ${mpi_app_path}
    if [[ "$?" -ne "${SUCCESS}" ]]; then
        echo ${APP_PATH_PERMISSION_ERROR}
        return
    fi
    # 判断二进制文件是否为软链接
    if [ -L ${mpi_app_path} ]; then
        echo ${APP_IS_LINK_ERROR}
        return
    fi
    # 判断二进制文件是否为可执行文件
    file_type=$(file -b --mime-encoding ${mpi_app_path})
    if [[ "${file_type}" != "binary" ]]; then
        echo ${APP_NOT_BINARY_ERROR}
        return
    fi
    # 判断源码路径是否存在
    if [ ! -e ${mpi_source_path} ]; then
        echo ${SOURCE_PATH_NOT_EXIT_ERROR}
        return
    fi
    # 判断应用程序源码路径有无Linux用户的可读、可执行权限
    test -r ${mpi_source_path} -a -x ${mpi_source_path}
    if [[ "$?" -ne "${SUCCESS}" ]]; then
        echo ${SOURCE_PATH_PERMISSION_ERROR}
        return
    fi
    # 判断应用程序源码路径是否为软链接
    if [ -L ${mpi_source_path} ]; then
        echo ${SOURCE_PATH_IS_LINK_ERROR}
        return
    fi
    # 检查应用程序源码路径是否为文件夹形式
    if [ ! -d ${mpi_source_path} ]; then
        echo ${SOURCE_PATH_NOT_DIR_ERROR}
        return
    fi
    echo ${RETURN_SUCCESS}
}

function main() {
    mpi_app_path="$1"
    mpi_source_path="$2"
    user_uuid="$3"
    mpi_app_dir_path=$(dirname "${mpi_app_path}")
    DEBUGGER_ENTRANCE_PATH="/usr/bin/devkit/debugger_entrance"
    pre_check_path
}

main "$@"