#!/bin/bash
#Description: DevKit constants
#Copyright: Copyright © Huawei Technologies Co., Ltd. 2023. All rights reserved.
#History: 2023-10-20 created
current_dir=$(cd $(dirname $0); pwd)
source "${current_dir}/const.sh"
source "${current_dir}/utils.sh"

function change_file_permission() {
    local file="$1"
    local num="$2"
    if [ -f "${file}" ]; then
        chmod "${num}" "${file}"
    fi
}

function init_env() {
    INSTALL_INI_PATH="${INSTALL_PATH}/config/install.ini"
    source ${INSTALL_PATH}/tools/log.sh
    if [[ ! -f "${INSTALL_INI_PATH}" ]]; then
		echo_and_log "There is no configure file(${INSTALL_INI_PATH}), please check!" "${ERROR}"
		exit "${ERROR}"
	fi
    USER_PATH="$(grep -w USER_PATH "${INSTALL_INI_PATH}" | awk -F= '{if($2 !="") print $2}')"
    USER_NAME="$(grep -w USER_NAME "${INSTALL_INI_PATH}" | awk -F= '{if($2 !="") print $2}')"
    CUDA_GDB_PATH=$(which cuda-gdb 2>/dev/null)
    DEVKIT_BIN="/usr/bin/devkit"
    DEBUGGER_ENTRANCE_PATH="/usr/bin/devkit/debugger_entrance"
    INSTALL_LOG_PATH="${INSTALL_PATH}/logs/install_plugins.log"
    PYTHON_PATH="${INSTALL_PATH}/tools/python_venv/bin/python3"
    if [[ -e ${CUDA_GDB_PATH} ]]; then
        CUDA_BIN_PATH="$(dirname ${CUDA_GDB_PATH})"
        echo "CUDA_GDB_BIN_PATH=${CUDA_BIN_PATH}" >> ${INSTALL_PATH}/devkitplugins/debugger/config/install.ini
    fi
}

function write_local_ip_to_config() {
    ip_addr=$(ip addr|grep inet|grep -v 127.0.0.1|grep -v inet6|awk '{print $2}' |tr '\n' ' ')
    echo "LOCAL_IP=${ip_addr}" >> ${INSTALL_PATH}/devkitplugins/debugger/config/install.ini
}

function copy_debugger_files() {
    if [[ ! -d ${DEVKIT_BIN} ]]; then
      mkdir -p ${DEVKIT_BIN}
      chmod -R 755 ${DEVKIT_BIN}
    fi
    if [[ ! -d ${DEBUGGER_ENTRANCE_PATH} ]]; then
        mkdir -p ${DEVKIT_BIN}/debugger_entrance
        chmod -R 755 ${DEVKIT_BIN}/debugger_entrance
    fi
    cp -f ${INSTALL_PATH}/tools/libdevkit_crypto.so ${DEBUGGER_ENTRANCE_PATH}
    chmod 755 ${DEBUGGER_ENTRANCE_PATH}/libdevkit_crypto.so
    debugger_lib_path=${INSTALL_PATH}/devkitplugins/debugger/cmd/lib
    cp -f ${debugger_lib_path}/libkmpi.so ${DEBUGGER_ENTRANCE_PATH}
    chmod 755 ${DEBUGGER_ENTRANCE_PATH}/libkmpi.so
    cp -f ${debugger_lib_path}/libstdc++.so* ${DEBUGGER_ENTRANCE_PATH}
    chmod 755 ${DEBUGGER_ENTRANCE_PATH}/libstdc++.so*
    debugger_bin_path=${INSTALL_PATH}/devkitplugins/debugger/cmd/bin
    cp -f ${debugger_bin_path}/lldb-server ${DEBUGGER_ENTRANCE_PATH}
    chmod 755 ${DEBUGGER_ENTRANCE_PATH}/lldb-server
    cp -f ${debugger_bin_path}/agent.tar.gz ${DEBUGGER_ENTRANCE_PATH}
    chmod 755 ${DEBUGGER_ENTRANCE_PATH}/agent.tar.gz
    cp -f ${debugger_bin_path}/encrypt ${DEBUGGER_ENTRANCE_PATH}
    chmod 755 ${DEBUGGER_ENTRANCE_PATH}/encrypt
    debugger_config_path=${INSTALL_PATH}/devkitplugins/debugger/config
    cp -f ${debugger_config_path}/*.sh ${DEBUGGER_ENTRANCE_PATH}
    chmod 755 ${DEBUGGER_ENTRANCE_PATH}/*.sh
    mkdir -p ${DEBUGGER_ENTRANCE_PATH}/temp
    chmod 757 ${DEBUGGER_ENTRANCE_PATH}/temp
    # 针对全局可修改文件添加粘滞位，避免安全问题
    chmod +t ${DEBUGGER_ENTRANCE_PATH}/temp
}

function main() {
    INSTALL_PATH="$1"
    plugin_flag="$2"  # web
    init_env
    if [[ "${plugin_flag}" == "web" ]]; then
		bash "${current_dir}/env_check.sh" "${INSTALL_PATH}" "${plugin_flag}"
		local check_res="$?"
        chmod 444 ${current_dir}/make_env_check_result.pyc
        su - "devkit" -s /bin/bash -c "${PYTHON_PATH} ${current_dir}/make_env_check_result.pyc"
        local temp_env_json="${current_dir}/debugger_env_res.json"
        local final_env_json="${INSTALL_PATH}/devkitplugins/check_env_result/debugger_env_res.json"
        if [[ -f "${temp_env_json}" ]]; then
            mv "${temp_env_json}" "${final_env_json}"
            chmod 600 "${final_env_json}"
            chown "${DEVKIT_USER}":"${DEVKIT_USER}" "${final_env_json}"
        fi
        if [[ "${check_res}" != "${SUCCESS}" ]]; then
            echo_and_log "Check install Dependent Packages Failed" "${ERROR}" "${INSTALL_LOG_PATH}"
            exit "${ERROR}"
        else
            echo_and_log "Check install Dependent Packages Success" "${SUCCESS}" "${INSTALL_LOG_PATH}"
        fi
    else
    	# 磁盘空间大小检测
        echo_and_log "Check disk space" "${DOING}" "${INSTALL_LOG_PATH}"
        disk_space_check "${INSTALL_PATH}" "${INSTALL_SPACE_NEED}"
        if [ "$?" -ne "${SUCCESS}" ]; then
            echo_and_log "Check install path disk space Failed" "${ERROR}" "${INSTALL_LOG_PATH}"
            exit "${ERROR}"
        fi
        echo_and_log "Check install path disk space Success" "${SUCCESS}" "${INSTALL_LOG_PATH}"
	fi
    write_local_ip_to_config
	change_file_permission "${INSTALL_PATH}/devkitplugins/debugger/config/request_param.conf" 600
    change_file_permission "${INSTALL_PATH}/devkitplugins/debugger/cmd/bin/encrypt" 500
	copy_debugger_files
	if [[ -e "${INSTALL_PATH}/devkitplugins/debugger/deploy/debugger_env_res.ini" ]]; then
	    rm -rf "${INSTALL_PATH}/devkitplugins/debugger/deploy/debugger_env_res.ini"
	fi
}

main "$@"